@@ -49,11 +49,11 @@
 /* Name of package.  */
 #define PACKAGE "grub"
 /* Version number of package.  */
-#define VERSION "2.04"
+#define VERSION "2.06"
 /* Define to the full name and version of this package. */
-#define PACKAGE_STRING "GRUB 2.04-20"
+#define PACKAGE_STRING "GRUB 2.06-3~deb11u5"
 /* Define to the version of this package. */
-#define PACKAGE_VERSION "2.04-20"
+#define PACKAGE_VERSION "2.06-3~deb11u5"
 /* Define to the full name of this package. */
 #define PACKAGE_NAME "GRUB"
 /* Define to the address where bug reports for this package should be sent. */
